==> osso-pdf-viewer_1.3.61-0.tar.gz: osso-pdf-viewer-1.3.61/src/ui/ui.h <==
/**
    @file ui.h

    Application user interface definitions.

    Copyright (c) 2004-2006 Nokia Corporation.
	
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
    02111-1307 USA
*/


#ifndef UI_H
#define UI_H


#include <gtk/gtk.h>

#include "callbacks.h"


/* Toolbar position for current page widget and
   total pages widget */
#define TOOLBAR_POS_CURRENT_PAGE_WIDGET 4
#define TOOLBAR_POS_CURRENT_ZOOM_WIDGET 10
#define TOOLBAR_POS_SHOW_IMAGES         13

#define TOOLBAR_POS_VISIBLE_SEPARATOR_A 1
#define TOOLBAR_POS_VISIBLE_SEPARATOR_B 6
#define TOOLBAR_POS_VISIBLE_SEPARATOR_C 9

/* Custom action names */
#define ACTION_PAGE_SWITCH_TO "pdfv_me_menu_page_switch_to"
#define ACTION_MENU_RECENT "pdfv_me_main_menu_recent"

/* Custom action paths */
#define ACTION_PATH_FULL_SCREEN "/MenuBar/pdfv_me_main_menu_view/pdfv_me_menu_screen_full_screen"

/* Use empty accelerator "" for stock action
   entries to disable stock accelerator */
static GtkActionEntry action_entries[] = {
    {"pdfv_me_main_menu_document", NULL, "pdfv_me_main_menu_document"},
#ifdef  VERSION_3
    {"pdfv_me_menu_document_send_main", NULL, "pdfv_me_menu_document_send_main"},
#endif
    {"pdfv_me_main_menu_page", NULL, "pdfv_me_main_menu_page"},
    {"pdfv_me_main_menu_view", NULL, "pdfv_me_main_menu_view"},
    {"pdfv_me_menu_screen_zoom", NULL,
     "pdfv_me_menu_screen_zoom"},
    //    {"pdfv_me_main_menu_tools", NULL, "pdfv_me_main_menu_tools"},
    {"pdfv_me_main_menu_recent", NULL, "pdfv_me_main_menu_recent"/*,NULL,NULL,G_CALLBACK(on_recent)*/},

    /* Document menu */

    {"pdfv_me_menu_document_open", "qgn_list_gene_fldr_opn",
     "pdfv_me_menu_document_open", "", NULL,
     G_CALLBACK(on_document_open)},

    {"pdfv_me_menu_document_save", GTK_STOCK_SAVE,
     "pdfv_me_menu_document_save", "", NULL,
     G_CALLBACK(on_document_save)},

    {"pdfv_me_menu_document_send", NULL,
     "pdfv_me_menu_document_send", NULL, NULL,
     G_CALLBACK(on_document_send)},
#ifdef  VERSION_3
     {"pdfv_me_menu_document_send_bluetooth", NULL,
     "pdfv_me_menu_document_send_bluetooth", NULL, NULL,
     G_CALLBACK(on_document_send_bt)},
#endif
    {"pdfv_me_menu_document_details", GTK_STOCK_PROPERTIES,
     "pdfv_me_menu_document_details", "", NULL,
     G_CALLBACK(on_document_details)},

    /* Page menu */
    /* No stock icon available for previous, next? */

    {"pdfv_me_menu_page_previous", "qgn_list_gene_back",
     "pdfv_me_menu_page_previous", NULL, NULL,
     G_CALLBACK(on_page_previous)},

    {"pdfv_me_menu_page_next", "qgn_list_gene_forward",
     "pdfv_me_menu_page_next", NULL, NULL,
     G_CALLBACK(on_page_next)},

    {"pdfv_me_menu_page_first", "qgn_list_documentviewer_first_page",
     "pdfv_me_menu_page_first", "", NULL,
     G_CALLBACK(on_page_first)},

    {"pdfv_me_menu_page_last", "qgn_list_documentviewer_last_page",
     "pdfv_me_menu_page_last", "", NULL,
     G_CALLBACK(on_page_last)},
/*	
	{ "pdfv_me_menu_page_switch_to", NULL,
	  "pdfv_me_menu_page_switch_to", NULL, NULL, 
	  G_CALLBACK(on_undefined_action) },
*/
    /* Screen menu, Zoom submenu */

    {"pdfv_me_menu_screen_zoom_in", "qgn_toolb_gene_zoomin",
     "pdfv_me_menu_screen_zoom_in", "", NULL,
     G_CALLBACK(on_screen_zoom_in)},

    {"pdfv_me_menu_screen_zoom_out", "qgn_toolb_gene_zoomout",
     "pdfv_me_menu_screen_zoom_out", "", NULL,
     G_CALLBACK(on_screen_zoom_out)},

    {"pdfv_me_menu_screen_zoom_page", GTK_STOCK_ZOOM_FIT,
     "pdfv_me_menu_screen_zoom_page", "", NULL,
     G_CALLBACK(on_screen_zoom_page)},

    {"pdfv_me_menu_screen_zoom_width", GTK_STOCK_ZOOM_100,
     "pdfv_me_menu_screen_zoom_width", "", NULL,
     G_CALLBACK(on_screen_zoom_width)},

    /* Tools menu */
    {"pdfv_me_menu_tools_help", GTK_STOCK_HELP,
     "pdfv_me_menu_tools_help", "", NULL,
     G_CALLBACK(on_tools_help)},

    /* TODO Recent menu */
    
    {"ignore_this_1", NULL,
     "ignore_this_1", NULL, NULL,
     G_CALLBACK(on_recent_document)},

    {"ignore_this_2", NULL,
     "ignore_this_2", NULL, NULL,
     G_CALLBACK(on_recent_document)},

    {"ignore_this_3", NULL,
     "ignore_this_3", NULL, NULL,
     G_CALLBACK(on_recent_document)},

    {"ignore_this_4", NULL,
     "ignore_this_4", NULL, NULL,
     G_CALLBACK(on_recent_document)},

    {"ignore_this_5", NULL,
     "ignore_this_5", NULL, NULL,
     G_CALLBACK(on_recent_document)},

    {"ignore_this_6", NULL,
     "ignore_this_6", NULL, NULL,
     G_CALLBACK(on_recent_document)},

    {"pdfv_me_main_menu_close", GTK_STOCK_CLOSE,
     "pdfv_me_main_menu_close", "", NULL,
     G_CALLBACK(on_close)},
};
static guint n_action_entries = G_N_ELEMENTS(action_entries);


static GtkToggleActionEntry toggle_action_entries[] = {
    {"pdfv_me_menu_screen_full_screen", NULL,
     "pdfv_me_menu_screen_full_screen", NULL, NULL,
     G_CALLBACK(on_screen_full_screen),
     FALSE},

    {"pdfv_me_menu_screen_show_images", "qgn_indi_gene_images_attachment",
     "pdfv_me_menu_screen_show_images", NULL, NULL,
     G_CALLBACK(on_screen_show_images),
     TRUE},
};
static guint n_toggle_action_entries = G_N_ELEMENTS(toggle_action_entries);


/* added separators between all toolbar buttons
   Expand is enabled programmatically since expand='true' does not work
   in current Gtk version. See build_toolbar() in interface.c.
   See also P12669-T-496 / Bugzilla 18292. */
static const gchar *ui_info =
    "<ui>"
    "  <menubar name='MenuBar'>"
    "    <menu action='pdfv_me_main_menu_document'>"
    "      <menuitem action='pdfv_me_menu_document_open'/>"
    "      <menuitem action='pdfv_me_menu_document_save'/>"
#ifdef  VERSION_3
    "      <separator name='Sep9'/>"
    "      <menu action='pdfv_me_menu_document_send_main'>"
#endif
    "        <menuitem action='pdfv_me_menu_document_send'/>"
#ifdef  VERSION_3
    "        <menuitem action='pdfv_me_menu_document_send_bluetooth'/>"
    "      </menu>"
#endif
    "      <separator name='Sep1'/>"
    "      <menuitem action='pdfv_me_menu_document_details'/>"
    "    </menu>"
    "    <menu action='pdfv_me_main_menu_page'>"
    "      <menuitem action='pdfv_me_menu_page_previous'/>"
    "      <menuitem action='pdfv_me_menu_page_next'/>"
    "      <separator name='Sep2'/>"
    "      <menuitem action='pdfv_me_menu_page_first'/>"
    "      <menuitem action='pdfv_me_menu_page_last'/>"
    "      <menuitem action='pdfv_me_menu_page_switch_to'/>"
    "    </menu>"
    "    <menu action='pdfv_me_main_menu_view'>"
    "      <menuitem action='pdfv_me_menu_screen_show_images'/>"
    "      <menu action='pdfv_me_menu_screen_zoom'>"
    "        <menuitem action='pdfv_me_menu_screen_zoom_in'/>"
    "        <menuitem action='pdfv_me_menu_screen_zoom_out'/>"
    "        <separator name='Sep3'/>"
    "        <menuitem action='pdfv_me_menu_screen_zoom_page'/>"
    "        <menuitem action='pdfv_me_menu_screen_zoom_width'/>"
    "      </menu>"
    "      <menuitem action='pdfv_me_menu_screen_full_screen'/>"
    "    </menu>"
  //    "    <menu action='pdfv_me_main_menu_tools'>"
  //    "      <menuitem action='pdfv_me_menu_tools_help'/>"
  //    "    </menu>"
    "    <menu action='pdfv_me_main_menu_recent'>"
    "      <menuitem action='ignore_this_1'/>"
    "      <menuitem action='ignore_this_2'/>"
    "      <menuitem action='ignore_this_3'/>"
    "      <menuitem action='ignore_this_4'/>"
    "      <menuitem action='ignore_this_5'/>"
    "      <menuitem action='ignore_this_6'/>"
    "    </menu>"
    "    <menuitem action='pdfv_me_menu_tools_help'/>"
    "    <menuitem action='pdfv_me_main_menu_close'/>"
    "  </menubar>"
    "  <toolbar name='ToolBar'>"
    "    <toolitem action='pdfv_me_menu_document_open'/>"
    "    <separator name='tbsep1'/>"        /* visible separator a */
//    "    <separator name='tbsep2'/>"
    "    <toolitem action='pdfv_me_menu_page_first'/>"
//    "    <separator name='tbsep3'/>"
    "    <toolitem action='pdfv_me_menu_page_previous'/>"
    "    <toolitem action='pdfv_me_menu_page_next'/>"
    "    <toolitem action='pdfv_me_menu_page_last'/>"
//    "    <separator name='tbsep4'/>"
    "    <separator name='tbsep5'/>"        /* visible separator b */
    "    <toolitem action='pdfv_me_menu_screen_zoom_out'/>"
//    "    <separator name='tbsep6'/>"
    "    <toolitem action='pdfv_me_menu_screen_zoom_in'/>"
    "    <separator name='tbsep7'/>"        /* visible separator c */
    "    <toolitem action='pdfv_me_menu_screen_show_images'/>"
    "  </toolbar>"
    "  <popup name='Popup'>"
    "    <menuitem action='pdfv_me_menu_page_previous'/>"
    "    <menuitem action='pdfv_me_menu_page_next'/>"
    "    <separator name='Sep1'/>"
    "    <menuitem action='pdfv_me_menu_screen_full_screen'/>"
    "    <menuitem action='pdfv_me_menu_screen_zoom_in'/>"
    "    <menuitem action='pdfv_me_menu_screen_zoom_out'/>"
#ifdef  VERSION_3
    "      <menu action='pdfv_me_menu_document_send_main'>"
#else
    "    <separator name='Sep2'/>"
#endif
    "        <menuitem action='pdfv_me_menu_document_send'/>"
#ifdef  VERSION_3
    "        <menuitem action='pdfv_me_menu_document_send_bluetooth'/>"
    "      </menu>"
#endif
    "    <menuitem action='pdfv_me_menu_document_details'/>"
    "    <separator name='Sep3'/>"
    "    <menuitem action='pdfv_me_menu_tools_help'/>"
    "  </popup>" "</ui>";

#endif				/* UI_H */

==> osso-pdf-viewer_1.4.41-0.tar.gz: osso-pdf-viewer-1.4.41/src/ui/ui.h <==
/**
    @file ui.h

    Application user interface definitions.

    Copyright (c) 2004-2006 Nokia Corporation.
	
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
    02111-1307 USA
*/


#ifndef UI_H
#define UI_H


#include <gtk/gtk.h>

#include "callbacks.h"


/* Toolbar position for current page widget and total pages widget */
#define TOOLBAR_POS_CURRENT_PAGE_WIDGET 4
#define TOOLBAR_POS_CURRENT_ZOOM_WIDGET 10
#define TOOLBAR_POS_SHOW_IMAGES         13

#define TOOLBAR_POS_VISIBLE_SEPARATOR_A 1
#define TOOLBAR_POS_VISIBLE_SEPARATOR_B 6
#define TOOLBAR_POS_VISIBLE_SEPARATOR_C 9

/* Custom action names */
#define ACTION_PAGE_SWITCH_TO "pdfv_me_menu_page_switch_to"
#define ACTION_MENU_RECENT "pdfv_me_main_menu_recent"

/* Custom action paths */
#define ACTION_PATH_FULL_SCREEN "/MenuBar/pdfv_me_main_menu_view/pdfv_me_menu_screen_full_screen"

/* Use empty accelerator "" for stock action entries to disable stock
 * accelerator */
static GtkActionEntry action_entries[] = {
    {"pdfv_me_main_menu_document", NULL, "pdfv_me_main_menu_document"},
    {"pdfv_me_menu_document_send_main", NULL,
     "pdfv_me_menu_document_send_main"},
    {"pdfv_me_main_menu_page", NULL, "pdfv_me_main_menu_page"},
    {"pdfv_me_main_menu_view", NULL, "pdfv_me_main_menu_view"},
    {"pdfv_me_menu_screen_zoom", NULL,
     "pdfv_me_menu_screen_zoom"},

    /* Document menu */

    {"pdfv_me_menu_document_open", "qgn_list_gene_fldr_opn",
     "pdfv_me_menu_document_open", "<Control>O", NULL,
     G_CALLBACK(on_document_open)},

    {"pdfv_me_menu_document_save", GTK_STOCK_SAVE,
     "pdfv_me_menu_document_save", "<Ctrl>s", NULL,
     G_CALLBACK(on_document_save)},
    {"pdfv_me_menu_document_send", NULL,
     "pdfv_me_menu_document_send", NULL, NULL,
     G_CALLBACK(on_document_send)},
    {"pdfv_me_menu_document_send_bluetooth", NULL,
     "pdfv_me_menu_document_send_bluetooth", NULL, NULL,
     G_CALLBACK(on_document_send_bt)},
    {"pdfv_me_menu_document_details", GTK_STOCK_PROPERTIES,
     "pdfv_me_menu_document_details", "", NULL,
     G_CALLBACK(on_document_details)},

    /* Page menu */
    /* No stock icon available for previous, next? */

    {"pdfv_me_menu_page_previous", "qgn_list_gene_back",
     "pdfv_me_menu_page_previous", NULL, NULL,
     G_CALLBACK(on_page_previous)},

    {"pdfv_me_menu_page_next", "qgn_list_gene_forward",
     "pdfv_me_menu_page_next", NULL, NULL,
     G_CALLBACK(on_page_next)},

    {"pdfv_me_menu_page_first", "qgn_list_documentviewer_first_page",
     "pdfv_me_menu_page_first", "", NULL,
     G_CALLBACK(on_page_first)},

    {"pdfv_me_menu_page_last", "qgn_list_documentviewer_last_page",
     "pdfv_me_menu_page_last", "", NULL,
     G_CALLBACK(on_page_last)},
    /* Screen menu, Zoom submenu */

    {"pdfv_me_menu_screen_zoom_in", "qgn_toolb_gene_zoomin",
     "pdfv_me_menu_screen_zoom_in", "", NULL,
     G_CALLBACK(on_screen_zoom_in)},

    {"pdfv_me_menu_screen_zoom_out", "qgn_toolb_gene_zoomout",
     "pdfv_me_menu_screen_zoom_out", "", NULL,
     G_CALLBACK(on_screen_zoom_out)},

    {"pdfv_me_menu_screen_zoom_page", GTK_STOCK_ZOOM_FIT,
     "pdfv_me_menu_screen_zoom_page", "", NULL,
     G_CALLBACK(on_screen_zoom_page)},

    {"pdfv_me_menu_screen_zoom_width", GTK_STOCK_ZOOM_100,
     "pdfv_me_menu_screen_zoom_width", "", NULL,
     G_CALLBACK(on_screen_zoom_width)},

    /* Tools menu */
    {"pdfv_me_menu_tools_help", GTK_STOCK_HELP,
     "pdfv_me_menu_tools_help", "", NULL,
     G_CALLBACK(on_tools_help)},

    {"pdfv_me_main_menu_close", GTK_STOCK_CLOSE,
     "pdfv_me_main_menu_close", "<Ctrl>q", NULL,
     G_CALLBACK(on_close)},
};
static guint n_action_entries = G_N_ELEMENTS(action_entries);


static GtkToggleActionEntry toggle_action_entries[] = {
    {"pdfv_me_menu_screen_full_screen", NULL,
     "pdfv_me_menu_screen_full_screen", NULL, NULL,
     G_CALLBACK(on_screen_full_screen),
     FALSE},

    {"pdfv_me_menu_screen_show_images", "qgn_indi_gene_images_attachment",
     "pdfv_me_menu_screen_show_images", NULL, NULL,
     G_CALLBACK(on_screen_show_images),
     TRUE},
};
static guint n_toggle_action_entries = G_N_ELEMENTS(toggle_action_entries);


/* added separators between all toolbar buttons Expand is enabled
 * programmatically since expand='true' does not work in current Gtk version. 
 * See build_toolbar() in interface.c. See also P12669-T-496 / Bugzilla
 * 18292. */
static const gchar *ui_info = 
    "<ui>" 
    "  <menubar name='MenuBar'>"
    "    <menu action='pdfv_me_main_menu_document'>" 
    "      <menuitem action='pdfv_me_menu_document_open'/>" 
    "      <menuitem action='pdfv_me_menu_document_save'/>" 
    "      <separator name='Sep9'/>" 
    "      <menu action='pdfv_me_menu_document_send_main'>" 
    "        <menuitem action='pdfv_me_menu_document_send'/>" 
    "        <menuitem action='pdfv_me_menu_document_send_bluetooth'/>" 
    "      </menu>" 
    "      <separator name='Sep1'/>" 
    "      <menuitem action='pdfv_me_menu_document_details'/>" 
    "    </menu>" 
    "    <menu action='pdfv_me_main_menu_page'>" 
    "      <menuitem action='pdfv_me_menu_page_previous'/>" 
    "      <menuitem action='pdfv_me_menu_page_next'/>" 
    "      <separator name='Sep2'/>" 
    "      <menuitem action='pdfv_me_menu_page_first'/>" 
    "      <menuitem action='pdfv_me_menu_page_last'/>" 
    "      <menuitem action='pdfv_me_menu_page_switch_to'/>" 
    "    </menu>" 
    "    <menu action='pdfv_me_main_menu_view'>" 
    "      <menuitem action='pdfv_me_menu_screen_show_images'/>" 
    "      <menu action='pdfv_me_menu_screen_zoom'>" 
    "        <menuitem action='pdfv_me_menu_screen_zoom_in'/>" 
    "        <menuitem action='pdfv_me_menu_screen_zoom_out'/>" 
    "        <separator name='Sep3'/>" 
    "        <menuitem action='pdfv_me_menu_screen_zoom_page'/>" 
    "        <menuitem action='pdfv_me_menu_screen_zoom_width'/>" 
    "      </menu>" 
    "      <menuitem action='pdfv_me_menu_screen_full_screen'/>" 
    "    </menu>" 
    "    <menuitem action='pdfv_me_menu_tools_help'/>" 
    "    <menuitem action='pdfv_me_main_menu_close'/>" 
    "  </menubar>" 
    "  <toolbar name='ToolBar'>" 
    "    <toolitem action='pdfv_me_menu_document_open'/>" 
    "    <separator name='tbsep1'/>"   /* visible separator a */
    "    <toolitem action='pdfv_me_menu_page_first'/>" 
    "    <toolitem action='pdfv_me_menu_page_previous'/>" 
    "    <toolitem action='pdfv_me_menu_page_next'/>" 
    "    <toolitem action='pdfv_me_menu_page_last'/>" 
    "    <separator name='tbsep5'/>"   /* visible separator b */
    "    <toolitem action='pdfv_me_menu_screen_zoom_out'/>" 
    "    <toolitem action='pdfv_me_menu_screen_zoom_in'/>" 
    "    <separator name='tbsep7'/>" /* visible separator c */
    "    <toolitem action='pdfv_me_menu_screen_show_images'/>"
    "  </toolbar>"
    "  <popup name='Popup'>"
    "    <menuitem action='pdfv_me_menu_page_previous'/>"
    "    <menuitem action='pdfv_me_menu_page_next'/>"
    "    <separator name='Sep1'/>"
    "    <menuitem action='pdfv_me_menu_screen_full_screen'/>"
    "    <menuitem action='pdfv_me_menu_screen_zoom_in'/>"
    "    <menuitem action='pdfv_me_menu_screen_zoom_out'/>"
    "      <menu action='pdfv_me_menu_document_send_main'>"
    "        <menuitem action='pdfv_me_menu_document_send'/>"
    "        <menuitem action='pdfv_me_menu_document_send_bluetooth'/>"
    "      </menu>"
    "    <menuitem action='pdfv_me_menu_document_details'/>"
    "    <separator name='Sep3'/>"
    "    <menuitem action='pdfv_me_menu_tools_help'/>" "  </popup>" "</ui>";

#endif /* UI_H */
